#include <QPixmap>
#include <QRect>
#include <QPalette>
#include <QDesktopWidget>
#include <settings.h>

#include "image.h"

Image::Image(PlaylistItem *item, QWidget *parent)
    : QLabel(parent)
    , Runnable()
{
    m_time = item->time();
    m_uri = item->uri();
    setAlignment(Qt::AlignCenter);
    setBlackBackground();
    buildPixmap();

    QLabel::connect(&m_timer, SIGNAL(timeout()), this, SLOT(onTimeout()));
}

void Image::setBlackBackground()
{
    QPalette p;
    p.setColor(QPalette::Background, Qt::black);
    QLabel::setAutoFillBackground(true);
    QLabel::setPalette(p);
}

void Image::buildPixmap()
{
    QPixmap pixmap;
    int p_w, p_h, s_w, s_h;

    QString path = m_uri.mid(7);
    QPixmap source(path);
    if (source.isNull())
    {
        setPixmap(source);
        return;
    }

    QRect g = qobject_cast<QWidget *>(QLabel::parent())->geometry();
    p_w = g.width();
    p_h = g.height();
    s_w = source.width();
    s_h = source.height();

    qDebug()<<p_w<<p_h<<s_w<<s_h;
    Settings  *settings = Settings::load();
    if(settings->get("slideshow/resize").toBool()){
        pixmap = source.scaled(p_w,p_h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
    }
    else if ((s_w <= p_w) && (s_h <= p_h)){
        pixmap = source;
    }
    else{
        pixmap = source.scaled(p_w,p_h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
    }
    setPixmap(pixmap);
}

void Image::run()
{
    if (pixmap()->isNull())
    {
        emit(end());
        return;
    }

    m_timer.start(1000 * m_time);
}

void Image::onTimeout()
{
    m_timer.stop();
    emit(end());
}

void Image::stop()
{
    m_timer.stop();
}
